{% extends 'base.html' %}
{% load static %}

{% block title %}
    Thanks
{% endblock %}

{% block content %}
    <h1 class="h1 d-block mt-5 text-center">Thanks</h1>
    <div class="mt-3 pt-2">
        <p class="alert alert-success mt-4 mx-auto">
            Your account has been created. Please check your email for the activation link.
            <a href="/" class="d-block mt-2">Click here to go back to the home page</a>
        </p>
    </div>
{% endblock %}
