{% extends 'base.html' %}
{% load static %}

{% block title %}
    Login
{% endblock %}
{% block content %}
<div class="mt-5 col-md-6 col-lg-4 mx-auto">
    <h1 class="my-5 pt-5">Hello</h1>
        {% if error_message %}
            <div class="alert alert-danger">{{ error_message }}</div>
        {% endif %}
        <form class="form" action="/login/" method="POST" >
            {% csrf_token %}
            <div class="form-group">
                <label class="pb-2 label" for="email">Email address</label>
                <input name="email" type="email" class="form-control " />
            </div>
            <div class="form-group mt-4">
                <label class="pb-2 label" for="password">Password</label>
                <input name="password" type="password" class="form-control" />
            </div>
            <div class="form-group mt-5">
                <button type="submit" class="btn btn-success btn-lg">Login</button>
            </div>
        </form>
    </div>
{% endblock %}
